@@ -2,10 +2,13 @@ import base64
 
 import cv2
 import numpy as np
-from turbojpeg import TurboJPEG
 
 
-jpeg = TurboJPEG()
+try:
+    from turbojpeg import TurboJPEG
+    jpeg = TurboJPEG()
+except Exception:
+    jpeg = None
 
 
 def decode_image_cv2(b64encoded):
@@ -24,9 +27,9 @@ def decode_image_turbojpeg(b64encoded):
 
 
 def decode_image(b64encoded):
-    try:
+    if jpeg is not None:
         img = decode_image_turbojpeg(b64encoded)
-    except Exception:
+    else:
         img = decode_image_cv2(b64encoded)
     return img
 
@@ -45,8 +48,8 @@ def encode_image_cv2(img, quality=90):
 
 
 def encode_image(img):
-    try:
+    if jpeg is not None:
         img = encode_image_turbojpeg(img)
-    except Exception:
+    else:
         img = encode_image_cv2(img)
     return img
